vip\_hci package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   vip_hci.config
   vip_hci.fits
   vip_hci.fm
   vip_hci.greedy
   vip_hci.invprob
   vip_hci.metrics
   vip_hci.objects
   vip_hci.preproc
   vip_hci.psfsub
   vip_hci.stats
   vip_hci.var

Submodules
----------

vip\_hci.vip\_ds9 module
------------------------

.. automodule:: vip_hci.vip_ds9
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci
   :members:
   :undoc-members:
   :show-inheritance:
